import type { Aes256Key, AesKey } from "./Aes.js";
import type { RsaEccKeyPair, RsaKeyPair, RsaPrivateKey } from "./RsaKeyPair.js";
import { KyberPrivateKey } from "./Liboqs/KyberKeyPair.js";
import { EccPrivateKey } from "./Ecc.js";
import { AsymmetricKeyPair } from "./AsymmetricKeyPair.js";
import type { PQKeyPairs } from "./PQKeyPairs.js";
export type EncryptedKeyPairs = EncryptedPqKeyPairs | EncryptedRsaKeyPairs | EncryptedRsaEccKeyPairs;
export type EncryptedPqKeyPairs = {
    pubEccKey: Uint8Array;
    pubKyberKey: Uint8Array;
    pubRsaKey: null;
    symEncPrivEccKey: Uint8Array;
    symEncPrivKyberKey: Uint8Array;
    symEncPrivRsaKey: null;
};
export type EncryptedRsaKeyPairs = {
    pubEccKey: null;
    pubKyberKey: null;
    pubRsaKey: Uint8Array;
    symEncPrivEccKey: null;
    symEncPrivKyberKey: null;
    symEncPrivRsaKey: Uint8Array;
};
export type EncryptedRsaEccKeyPairs = {
    pubEccKey: Uint8Array;
    pubKyberKey: null;
    pubRsaKey: Uint8Array;
    symEncPrivEccKey: Uint8Array;
    symEncPrivKyberKey: null;
    symEncPrivRsaKey: Uint8Array;
};
export declare function encryptKey(encryptionKey: AesKey, keyToBeEncrypted: AesKey): Uint8Array;
export declare function decryptKey(encryptionKey: AesKey, keyToBeDecrypted: Uint8Array): AesKey;
export declare function aes256DecryptWithRecoveryKey(encryptionKey: Aes256Key, keyToBeDecrypted: Uint8Array): Aes256Key;
export declare function encryptRsaKey(encryptionKey: AesKey, privateKey: RsaPrivateKey, iv?: Uint8Array): Uint8Array;
export declare function encryptEccKey(encryptionKey: AesKey, privateKey: EccPrivateKey): Uint8Array;
export declare function encryptKyberKey(encryptionKey: AesKey, privateKey: KyberPrivateKey): Uint8Array;
export declare function decryptRsaKey(encryptionKey: AesKey, encryptedPrivateKey: Uint8Array): RsaPrivateKey;
export declare function decryptKeyPair(encryptionKey: AesKey, keyPair: EncryptedPqKeyPairs): PQKeyPairs;
export declare function decryptKeyPair(encryptionKey: AesKey, keyPair: EncryptedRsaKeyPairs): RsaKeyPair;
export declare function decryptKeyPair(encryptionKey: AesKey, keyPair: EncryptedRsaEccKeyPairs): RsaEccKeyPair;
export declare function decryptKeyPair(encryptionKey: AesKey, keyPair: EncryptedKeyPairs): AsymmetricKeyPair;
